{% extends 'cruditor/base.html' %}
{% load i18n %}
{% load floppyforms %}


{% block content %}
	<form action="{{ app_path }}" method="post" role="form">
		{% csrf_token %}
		{% form form using 'cruditor/forms/layout.html' %}
		<button class="btn btn-primary" type="submit">{% trans 'Change password' %}</button>
	</form>
{% endblock %}
