{% block content %}<input type="{{ type }}" name="{{ name }}"{% if value %} value="{{ value }}"{% endif %}{% if required %} required{% endif %}{% include "cruditor/forms/attrs.html" %}{% if datalist %} list="{{ attrs.id }}_list"{% endif %}>{% if datalist %}
<datalist id="{{ attrs.id }}_list">{% for item in datalist %}
	<option value="{{ item }}">{% endfor %}
</datalist>{% endif %}{% endblock %}
